Module api

Module api 

High-level API for LEPCC compression and decompression

This module provides convenient functions for compressing and decompressing point cloud data that can be used by other Rust projects.

Functions

compress_flag_bytes
Compress flag bytes (e.g., classification, return type)
compress_intensity
Compress intensity values
compress_rgb
Compress RGB colors from a color array
compress_rgb_array
Compress RGB colors from a flat u8 array
compress_xyz
Compress XYZ coordinates from a vertex array
compress_xyz_array
Compress XYZ coordinates from a flat f64 array
decompress_flag_bytes
Decompress flag bytes
decompress_intensity
Decompress intensity values
decompress_rgb
Decompress RGB colors from binary data
decompress_rgb_array
Decompress RGB colors to a flat u8 array
decompress_xyz
Decompress XYZ coordinates from binary data
decompress_xyz_array
Decompress XYZ coordinates to a flat f64 array
get_blob_size
Get the size of a compressed blob
get_blob_type
Get the blob type from compressed data
get_num_points
Get the number of points/values in compressed data