High-level API for LEPCC compression and decompression
This module provides convenient functions for compressing and decompressing point cloud data that can be used by other Rust projects.
Functions
- compress_
flag_ bytes - Compress flag bytes (e.g., classification, return type)
- compress_
intensity - Compress intensity values
- compress_
rgb - Compress RGB colors from a color array
- compress_
rgb_ array - Compress RGB colors from a flat u8 array
- compress_
xyz - Compress XYZ coordinates from a vertex array
- compress_
xyz_ array - Compress XYZ coordinates from a flat f64 array
- decompress_
flag_ bytes - Decompress flag bytes
- decompress_
intensity - Decompress intensity values
- decompress_
rgb - Decompress RGB colors from binary data
- decompress_
rgb_ array - Decompress RGB colors to a flat u8 array
- decompress_
xyz - Decompress XYZ coordinates from binary data
- decompress_
xyz_ array - Decompress XYZ coordinates to a flat f64 array
- get_
blob_ size - Get the size of a compressed blob
- get_
blob_ type - Get the blob type from compressed data
- get_
num_ points - Get the number of points/values in compressed data